==> mcrypt-2.5.6.tar.gz: mcrypt-2.5.6/src/environ.c <==
/*
 *    Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: environ.c,v 1.1.1.1 2000/05/22 13:09:26 nmav Exp $ */

#ifndef DEFINES_H
#define DEFINES_H
#include <defines.h>
#endif
#include <environ.h>
#include <extra.h>
#include <xmalloc.h>

static char rcsid[] = "$Id: environ.c,v 1.1.1.1 2000/05/22 13:09:26 nmav Exp $";

int check_env()
{

	if (getenv(MCRYPT_KEY) != NULL
	    || getenv(MCRYPT_ALGO) != NULL
	    || getenv(MCRYPT_MODE) != NULL)
		return TRUE;	/* ok */
	return FALSE;

}

char **
 get_env_key()
{
	char **tmp;

	if (getenv(MCRYPT_KEY) != NULL) {
		tmp = mcrypt_malloc(sizeof(char *));
		tmp[0] = getenv(MCRYPT_KEY);
		return tmp;
	} else {
		return NULL;
	}

}

char *
 get_env_algo()
{

	return getenv(MCRYPT_ALGO);

}

char *
 get_env_mode()
{

	return getenv(MCRYPT_MODE);

}

char *get_env_bit_mode()
{

	return getenv(MCRYPT_KEY_MODE);

}

==> mcrypt_2.6.4.orig.tar.gz: mcrypt-2.6.4/src/environ.c <==
/*
 *    Copyright (C) 1998,1999,2000 Nikos Mavroyanopoulos
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* $Id: environ.c,v 1.2 2001/09/02 20:20:43 nmav Exp $ */

#ifndef DEFINES_H
#define DEFINES_H
#include <defines.h>
#endif
#include <environ.h>
#include <extra.h>
#include <xmalloc.h>

static char rcsid[] = "$Id: environ.c,v 1.2 2001/09/02 20:20:43 nmav Exp $";

int check_env()
{

	if (getenv(MCRYPT_KEY) != NULL
	    || getenv(MCRYPT_ALGO) != NULL
	    || getenv(MCRYPT_MODE) != NULL)
		return TRUE;	/* ok */
	return FALSE;

}

char **
 get_env_key()
{
	char **tmp;

	if (getenv(MCRYPT_KEY) != NULL) {
		tmp = _mcrypt_malloc(sizeof(char *));
		tmp[0] = getenv(MCRYPT_KEY);
		return tmp;
	} else {
		return NULL;
	}

}

char *
 get_env_algo()
{

	return getenv(MCRYPT_ALGO);

}

char *
 get_env_mode()
{

	return getenv(MCRYPT_MODE);

}

char *get_env_bit_mode()
{

	return getenv(MCRYPT_KEY_MODE);

}
